@@ -9,7 +9,7 @@ use Moo;
 #use Perinci::Object;
 use Perinci::ToUtil;
 
-our $VERSION = '0.52'; # VERSION
+our $VERSION = '0.53'; # VERSION
 
 with 'Perinci::To::Text::AddDocLinesRole';
 with 'SHARYANTO::Role::Doc::Section';
@@ -30,6 +30,7 @@ has program_name => (
 has url => (is => 'rw');
 has summary => (is => 'rw');
 has subcommands => (is => 'rw');
+has default_subcommand => (is => 'rw');
 has exit => (is => 'rw', default=>sub{1});
 has log_any_app => (is => 'rw', default=>sub{$ENV{LOG} // 1});
 has custom_completer => (is => 'rw');
@@ -208,7 +209,8 @@ sub run_list {
 sub run_version {
     my ($self) = @_;
 
-    my $url = $self->{_subcommand} ? $self->{_subcommand}{url} : $self->url;
+    my $url = $self->{_subcommand} && $self->{_subcommand}{url} ?
+        $self->{_subcommand}{url} : $self->url;
     my $res = $self->_pa->request(meta => $url);
     my $ver;
     if ($res->[0] == 200) {
@@ -243,7 +245,7 @@ sub run_completion {
             $do_arg++; last;
         }
 
-        my $scn = $sc->{name};
+        my $scn = $sc->{name} // "";
 
         # whether user typed 'blah blah ^' or 'blah blah^'
         my $space_typed = !defined($word);
@@ -269,6 +271,7 @@ sub run_completion {
     my @top_opts; # contain --help, -h, etc.
     for my $o (keys %{{@{ $self->{_getopts_common} }}}) {
         $o =~ s/^--//;
+        $o =~ s/=.+$//;
         my @o = split /\|/, $o;
         for (@o) { push @top_opts, length > 1 ? "--$_" : "-$_" }
     }
@@ -378,7 +381,18 @@ sub doc_gen_usage {
     my ($self) = @_;
     my $text;
     if ($self->subcommands) {
-        $text = <<_;
+        if (defined $self->default_subcommand) {
+            $text = <<_;
+Usage:
+
+    [_1] --help (or -h, -?)
+    [_1] --version (or -v)
+    [_1] --list (or -l)
+    [_1] (common options) (options)
+    [_1] --cmd=OTHER_SUBCOMMAND (common options) (options)
+_
+        } else {
+            $text = <<_;
 Usage:
 
     [_1] --help (or -h, -?)
@@ -386,6 +400,7 @@ Usage:
     [_1] --list (or -l)
     [_1] SUBCOMMAND (common options) (options)
 _
+        }
     } else {
         $text = <<_;
 Usage:
@@ -627,32 +642,46 @@ sub gen_common_opts {
     $log->tracef("-> gen_common_opts()");
 
     my @getopts = (
-        "action=s"   => sub {
+        "action=s" => sub {
             # 'action=subcommand' can be used to override --help (or --list,
             # --version) if one of function arguments happens to be 'help',
-            # 'list', or 'version'. currently udocumented.
+            # 'list', or 'version'. currently this is undocumented.
             if ($_[1] eq 'subcommand') {
                 $self->{_force_subcommand} = 1;
             }
         },
-        "list|l"     => sub {
-            unshift @{$self->{_actions}}, 'list';
-            $self->{_check_required_args} = 0;
-        },
-        "version|v"  => sub {
+        "version|v" => sub {
             die "ERROR: 'url' not set, required for --version\n"
                 unless $self->url;
             unshift @{$self->{_actions}}, 'version';
             $self->{_check_required_args} = 0;
         },
-        "help|h|?"   => sub {
+        "help|h|?" => sub {
             unshift @{$self->{_actions}}, 'help';
             $self->{_check_required_args} = 0;
         },
 
-        "format=s"    => sub { $self->format($_[1])         },
+        "format=s" => sub { $self->format($_[1]) },
     );
 
+    if ($self->subcommands) {
+        push @getopts, (
+            "list|l"     => sub {
+                unshift @{$self->{_actions}}, 'list';
+                $self->{_check_required_args} = 0;
+            },
+        );
+        if (defined $self->default_subcommand) {
+            push @getopts, (
+                "cmd=s" => sub {
+                    # 'cmd=SUBCOMMAND_NAME' can be used to select other
+                    # subcommands when default_subcommand is in effect.
+                    $self->{_selected_subcommand} = $_[1];
+                },
+            );
+        }
+    }
+
     # convenience for Log::Any::App-using apps
     if ($self->log_any_app) {
         for (qw/quiet verbose debug trace log-level/) {
@@ -764,29 +793,35 @@ sub _set_subcommand {
     my ($self) = @_;
 
     if ($self->subcommands) {
-        if (@ARGV) {
-            my $scn = shift @ARGV;
+        my $scn;
+        if (defined $self->{_selected_subcommand}) {
+            $scn = $self->{_selected_subcommand};
+        } elsif (defined $self->default_subcommand) {
+            $scn = $self->default_subcommand;
+        } elsif (@ARGV) {
+            $scn = shift @ARGV;
             $self->{_scn_in_argv} = $scn;
             $scn =~ s/-/_/g if $self->dash_to_underscore;
-            my $sc = $self->get_subcommand($scn);
-            unless ($sc) {
-                if ($ENV{COMP_LINE}) {
-                    require Object::BlankStr;
-                    die Object::BlankStr->new;
-                } else {
-                    die "ERROR: Unknown subcommand '$scn', use '".
-                        $self->program_name.
-                            " -l' to list available subcommands\n";
-                }
-            }
-            $self->{_subcommand} = $sc;
-            $self->{_subcommand}{name} = $scn;
-            if ($self->{_force_subcommand}) {
-                unshift @{$self->{_actions}}, 'subcommand';
+        } else {
+            goto L1;
+        }
+        my $sc = $self->get_subcommand($scn);
+        unless ($sc) {
+            if ($ENV{COMP_LINE}) {
+                goto L1;
             } else {
-                push @{$self->{_actions}}, 'subcommand';
+                die "ERROR: Unknown subcommand '$scn', use '".
+                    $self->program_name.
+                        " -l' to list available subcommands\n";
             }
         }
+        $self->{_subcommand} = $sc;
+        $self->{_subcommand}{name} = $scn;
+        if ($self->{_force_subcommand}) {
+            unshift @{$self->{_actions}}, 'subcommand';
+        } else {
+            push @{$self->{_actions}}, 'subcommand';
+        }
     } else {
         $self->{_subcommand} = {url=>$self->url, summary=>$self->summary};
         $self->{_subcommand}{name} = '';
@@ -796,6 +831,7 @@ sub _set_subcommand {
             push @{$self->{_actions}}, 'subcommand';
         }
     }
+  L1:
     unshift @{$self->{_actions}}, 'completion' if $ENV{COMP_LINE};
     push @{$self->{_actions}}, 'help' if !@{$self->{_actions}};
 
@@ -892,7 +928,7 @@ Perinci::CmdLine - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
@@ -1005,6 +1041,11 @@ return a hashref of subcommand specifications. If called with argument C<name>
 it must return subcommand specification for subcommand with the requested name
 only.
 
+=head2 default_subcommand => NAME
+
+If set, subcommand will always be set to this instead of from the first
+argument. To use other subcommands, you will have to use --cmd option.
+
 =head2 exit => BOOL (default 1)
 
 If set to 0, instead of exiting with exit(), run() will return the exit code
