@@ -4,7 +4,7 @@ use parent qw(Perinci::CmdLine::I18N Perinci::To::Text::I18N::en);
 use Locale::Maketext::Lexicon::Gettext;
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 
-our $VERSION = '0.52'; # VERSION
+our $VERSION = '0.53'; # VERSION
 
 #use Data::Dump; dd \%Lexicon;
 
@@ -20,7 +20,7 @@ Perinci::CmdLine::I18N::en - English translation for Perinci::CmdLine
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 AUTHOR
 
@@ -53,6 +53,7 @@ msgstr "%1 version %2"
 
 # usage
 
+# help when there is no subcommands
 msgid  ""
 "Usage:\n"
 "\n"
@@ -66,6 +67,7 @@ msgstr ""
 "    %1 --version (or -v)\n"
 "    %1 [common options] [options]\n"
 
+# help when there is subcommands
 msgid  ""
 "Usage:\n"
 "\n"
@@ -81,6 +83,24 @@ msgstr ""
 "    %1 --list (or -l)\n"
 "    %1 SUBCOMMAND [common options] [options]\n"
 
+# help when there is subcommands + default_subcommand
+msgid  ""
+"Usage:\n"
+"\n"
+"    %1 --help (or -h, -?)\n"
+"    %1 --version (or -v)\n"
+"    %1 --list (or -l)\n"
+"    %1 (common options) (options)\n"
+"    %1 --cmd=OTHER_SUBCOMMAND (common options) (options)\n"
+msgstr ""
+"Usage:\n"
+"\n"
+"    %1 --help (or -h, -?)\n"
+"    %1 --version (or -v)\n"
+"    %1 --list (or -l)\n"
+"    %1 [common options] [options]\n"
+"    %1 --cmd=OTHER_SUBCOMMAND [common options] [options]\n"
+
 msgid  ""
 "Common options:\n"
 "\n"
